@@ -6,15 +6,25 @@ import requests
 class BaseService:
     """Singleton Base Service class"""
 
-    def __init__(self, base_url: str, api_key: str, **kwargs) -> None:
+    def __init__(
+        self,
+        base_url: str,
+        api_key: str,
+        session: Optional[requests.Session],
+        **kwargs,
+    ) -> None:
         self.base_url = base_url
         super().__init__(**kwargs)
 
-        # configure session
-        self.__session = requests.Session()
-        self.__session.headers.update({"Authorization": f"Key {api_key}"})
-        self.__session.headers.update({"Content-Type": "application/json"})
-        self.__session.headers.update({"Accept": "application/json"})
+        # Enable to pass a custom session
+        if isinstance(session, (requests.Session)):
+            self.__session = session
+        else:
+            # configure session
+            self.__session = requests.Session()
+            self.__session.headers.update({"Authorization": f"Key {api_key}"})
+            self.__session.headers.update({"Content-Type": "application/json"})
+            self.__session.headers.update({"Accept": "application/json"})
 
     @final
     def _request(
